@@ -1,15 +1,27 @@
 package urpm::removable;
 
-# $Id: removable.pm 250871 2009-01-06 17:21:05Z pixel $
 
 use strict;
 use urpm::msg;
 use urpm::sys;
-use urpm::util;
+use urpm::util 'reduce_pathname';
 use urpm 'file_from_local_medium';
 
 
 
+=head1 NAME
+
+urpm::removable - Removable media routines for urpmi
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=over
+
+=cut 
+
+
 sub file_or_synthesis_dir {
     my ($medium, $o_url) = @_;
     
@@ -72,13 +84,10 @@ sub _try_mounting_iso {
     if ($mntpoint) {
 	$urpm->{log}(N("mounting %s", $mntpoint));
 
-	#- to mount an iso image, grab the first loop device
-	my $loopdev = urpm::sys::first_free_loopdev();
 	sys_log("mount iso $mntpoint on $iso");
-	$loopdev and system('mount', $iso, $mntpoint, '-t', 'iso9660', '-o', "loop=$loopdev");
+	system('mount', $iso, $mntpoint, qw(-t iso9660 -o loop));
 	$urpm->{removable_mounted}{$mntpoint} = undef;
     }
-    -e $mntpoint;
 }
 
 #- side-effects: $urpm->{removable_mounted}, "mount"
@@ -93,7 +102,6 @@ sub _try_mounting_using_fstab {
 	system("mount '$mntpoint' 2>/dev/null");
 	$urpm->{removable_mounted}{$mntpoint} = undef;
     }
-    -e $dir;
 }
 
 #- side-effects: $urpm->{removable_mounted}, "umount"
@@ -153,3 +161,16 @@ sub _blist_first_url {
 }
 
 1;
+
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright (C) 2005 MandrakeSoft SA
+
+Copyright (C) 2005-2010 Mandriva SA
+
+Copyright (C) 2011-2017 Mageia
+
+=cut
